@@ -26,13 +26,14 @@ class HashItAnyway:
 
 class Tracker():
     def __init__(self):
-        self.contents = set()
+        self.contents = {}
 
-    def already_seen(self,x):
+    def track(self,x):
         k = HashItAnyway(x)
-        if k not in self.contents:
-            self.contents.add(k)
-            return False
-        else:
-            return True
+        n = self.contents.get(k, 0) + 1 
+        self.contents[k] = n
+        return n
 
+    def __iter__(self):
+        for k,v in self.contents.items():
+            yield k.wrapped, v
